==> openGion8.2.0.0_src.zip: uap/webapps/gf/src/org/opengion/plugin/column/Renderer_HM.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.plugin.column;

import org.opengion.hayabusa.db.AbstractRenderer;
import org.opengion.hayabusa.db.CellRenderer;
import org.opengion.hayabusa.db.DBColumn;

/**
 * HM レンデラーは、カラムのデータを時：分に分けて表示する場合に
 * 使用するクラスです。
 * 4桁以上6桁以下である必要があります。5,6桁目は無視されます。
 *
 *  カラムの表示に必要な属性は, DBColumn オブジェクト より取り出します。
 * このクラスは、DBColumn オブジェクト毎に１つ作成されます。
 *
 * @og.group データ表示
 * @og.rev 5.4.3.5 (2012/01/12) 新規作成
 *
 * @version  5.0
 * @author	 Takahashi Masakazu
 * @since    JDK5.0,
 */
public class Renderer_HM extends AbstractRenderer {
	/** このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "7.3.0.1 (2021/01/29)" ;

	private static final CellRenderer DB_CELL = new Renderer_HM() ; // 5.6.5.1 (2013/06/14)

	/**
	 * デフォルトコンストラクター
	 *
	 * @og.rev 6.4.2.0 (2016/01/29) PMD refactoring. Each class should declare at least one constructor.
	 */
	public Renderer_HM() { super(); }		// これも、自動的に呼ばれるが、空のメソッドを作成すると警告されるので、明示的にしておきます。

	/**
	 * 各オブジェクトから自分のインスタンスを返します。
	 * 自分自身をキャッシュするのか、新たに作成するのかは、各サブクラスの実装に
	 * まかされます。
	 *
	 * @param	clm	DBColumnオブジェクト
	 *
	 * @return	CellRendererオブジェクト
	 * @og.rtnNotNull
	 */
	public CellRenderer newInstance( final DBColumn clm ) {
		return DB_CELL;
	}

	/**
	 * データの表示用文字列を返します。
	 * ここでは、null か ゼロ文字列の場合は、ゼロ文字列を返します。
	 * ４ケタ、６ケタ、１４ケタでないデータは、エラー表示を行います。
	 * ４ケタの場合は、HHmm として、HH:MM として返します。
	 * ６ケタの場合は、HHmmss として、そのうちの時分の HH:MM のみ返します。
	 * １４ケタの場合は、yyyyMMddHHmmss として、そのうちの時分の HH:MM のみ返します。
	 *
	 * @og.rev 5.5.7.2 (2012/10/09) 処理ロジックの見直し
	 * @og.rev 5.6.5.0 (2013/06/07) １４ケタも処理するように変更
	 *
	 * @param	value 入力値
	 *
	 * @return	データの表示用文字列
	 */
	@Override
	public String getValue( final String value ) {
		return getValue( value , true );
	}

	/**
	 * データ出力用の文字列を作成します。
	 * ファイル等に出力する形式を想定しますので、HTMLタグを含まない
	 * データを返します。
	 * 基本は、#getValue( String ) をそのまま返します。
	 *
	 * @og.rev 6.0.4.0 (2014/11/28) データ出力用のレンデラー
	 *
	 * @param   value 入力値
	 *
	 * @return  データ出力用の文字列
	 * @see		#getValue( String )
	 */
	@Override
	public String getWriteValue( final String value ) {
		return getValue( value , false );
	}

	/**
	 * データ表示用/出力用の文字列を作成します。
	 * 第二引数の isView == true で、データ表示用文字列を、false で
	 * データ出力用の文字列を作成します。
	 * 処理の共通化を行うためのメソッドです。
	 *
	 * @og.rev 6.0.4.0 (2014/11/28) ロジックの共通化
	 * @og.rev 7.3.0.1 (2021/01/29) １４ケタのch1[4] rtn.charAt(1) → rtn.charAt(11) 修正
	 *
	 * @param   value  入力値
	 * @param   isView データ表示用かどうか(true:表示用/false:出力用)
	 *
	 * @return  データ表示用/出力用の文字列
	 * @og.rtnNotNull
	 * @see		#getValue( String )
	 */
	private String getValue( final String value , final boolean isView ) {
		if( value == null || value.isEmpty() ) { return ""; }

		String rtn = value;			// 初期値:isView = false の時の値
		if( rtn.length() == 4 || rtn.length() == 6 ) {
			char[] ch1 = new char[5];
			ch1[0] = rtn.charAt(0);
			ch1[1] = rtn.charAt(1);
			ch1[2] = ':' ;
			ch1[3] = rtn.charAt(2);
			ch1[4] = rtn.charAt(3);

			rtn = new String( ch1 );
		}
		// 5.6.5.0 (2013/06/07) １４ケタも処理する
		else if( rtn.length() == 14 ) {
			char[] ch1 = new char[5];
			ch1[0] = rtn.charAt(8);
			ch1[1] = rtn.charAt(9);
			ch1[2] = ':' ;
			ch1[3] = rtn.charAt(10);
			ch1[4] = rtn.charAt(11);				// 7.3.0.1 (2021/01/29)

			rtn = new String( ch1 );
		}
		else {
			if( isView ) {
				rtn = "<span class=\"error\">" + value + "</span>";
			}
		}
		return rtn;
	}
}

==> openGion8.5.2.0_src.zip: uap/webapps/gf/src/org/opengion/plugin/column/Renderer_HM.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.plugin.column;

import org.opengion.hayabusa.db.AbstractRenderer;
import org.opengion.hayabusa.db.CellRenderer;
import org.opengion.hayabusa.db.DBColumn;

/**
 * HM レンデラーは、カラムのデータを時：分に分けて表示する場合に
 * 使用するクラスです。
 * 4桁以上6桁以下である必要があります。5,6桁目は無視されます。
 *
 *  カラムの表示に必要な属性は、DBColumn オブジェクト より取り出します。
 * このクラスは、DBColumn オブジェクト毎に１つ作成されます。
 *
 * @og.group データ表示
 * @og.rev 5.4.3.5 (2012/01/12) 新規作成
 *
 * @version  5.0
 * @author	 Takahashi Masakazu
 * @since    JDK5.0,
 */
public class Renderer_HM extends AbstractRenderer {
	/** このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "7.3.0.1 (2021/01/29)" ;

	private static final CellRenderer DB_CELL = new Renderer_HM() ; // 5.6.5.1 (2013/06/14)

	/**
	 * デフォルトコンストラクター
	 *
	 * @og.rev 6.4.2.0 (2016/01/29) PMD refactoring. Each class should declare at least one constructor.
	 */
	public Renderer_HM() { super(); }		// これも、自動的に呼ばれるが、空のメソッドを作成すると警告されるので、明示的にしておきます。

	/**
	 * 各オブジェクトから自分のインスタンスを返します。
	 * 自分自身をキャッシュするのか、新たに作成するのかは、各サブクラスの実装に
	 * まかされます。
	 *
	 * @param	clm	DBColumnオブジェクト
	 *
	 * @return	CellRendererオブジェクト
	 * @og.rtnNotNull
	 */
	public CellRenderer newInstance( final DBColumn clm ) {
		return DB_CELL;
	}

	/**
	 * データの表示用文字列を返します。
	 * ここでは、null か ゼロ文字列の場合は、ゼロ文字列を返します。
	 * ４ケタ、６ケタ、１４ケタでないデータは、エラー表示を行います。
	 * ４ケタの場合は、HHmm として、HH:MM として返します。
	 * ６ケタの場合は、HHmmss として、そのうちの時分の HH:MM のみ返します。
	 * １４ケタの場合は、yyyyMMddHHmmss として、そのうちの時分の HH:MM のみ返します。
	 *
	 * @og.rev 5.5.7.2 (2012/10/09) 処理ロジックの見直し
	 * @og.rev 5.6.5.0 (2013/06/07) １４ケタも処理するように変更
	 *
	 * @param	value 入力値
	 *
	 * @return	データの表示用文字列
	 */
	@Override
	public String getValue( final String value ) {
		return getValue( value , true );
	}

	/**
	 * データ出力用の文字列を作成します。
	 * ファイル等に出力する形式を想定しますので、HTMLタグを含まない
	 * データを返します。
	 * 基本は、#getValue( String ) をそのまま返します。
	 *
	 * @og.rev 6.0.4.0 (2014/11/28) データ出力用のレンデラー
	 *
	 * @param   value 入力値
	 *
	 * @return  データ出力用の文字列
	 * @see		#getValue( String )
	 */
	@Override
	public String getWriteValue( final String value ) {
		return getValue( value , false );
	}

	/**
	 * データ表示用/出力用の文字列を作成します。
	 * 第二引数の isView == true で、データ表示用文字列を、false で
	 * データ出力用の文字列を作成します。
	 * 処理の共通化を行うためのメソッドです。
	 *
	 * @og.rev 6.0.4.0 (2014/11/28) ロジックの共通化
	 * @og.rev 7.3.0.1 (2021/01/29) １４ケタのch1[4] rtn.charAt(1) → rtn.charAt(11) 修正
	 *
	 * @param   value  入力値
	 * @param   isView データ表示用かどうか(true:表示用/false:出力用)
	 *
	 * @return  データ表示用/出力用の文字列
	 * @og.rtnNotNull
	 * @see		#getValue( String )
	 */
	private String getValue( final String value , final boolean isView ) {
		if( value == null || value.isEmpty() ) { return ""; }

		String rtn = value;			// 初期値:isView = false の時の値
		if( rtn.length() == 4 || rtn.length() == 6 ) {
			char[] ch1 = new char[5];
			ch1[0] = rtn.charAt(0);
			ch1[1] = rtn.charAt(1);
			ch1[2] = ':' ;
			ch1[3] = rtn.charAt(2);
			ch1[4] = rtn.charAt(3);

			rtn = new String( ch1 );
		}
		// 5.6.5.0 (2013/06/07) １４ケタも処理する
		else if( rtn.length() == 14 ) {
			char[] ch1 = new char[5];
			ch1[0] = rtn.charAt(8);
			ch1[1] = rtn.charAt(9);
			ch1[2] = ':' ;
			ch1[3] = rtn.charAt(10);
			ch1[4] = rtn.charAt(11);				// 7.3.0.1 (2021/01/29)

			rtn = new String( ch1 );
		}
		else {
			if( isView ) {
				rtn = "<span class=\"error\">" + value + "</span>";
			}
		}
		return rtn;
	}
}
